@@ -10,10 +10,10 @@ LinkedSphereGeom <- R6::R6Class(
     use_link = FALSE,
 
     to_list = function(){
-      re = super$to_list()
-      re$use_link = self$use_link
-      re$vertex_number = self$vertex_number
-      re$linked_geom = self$linked_geom$name
+      re <- super$to_list()
+      re$use_link <- self$use_link
+      re$vertex_number <- self$vertex_number
+      re$linked_geom <- self$linked_geom$name
       re
     }
 
